==> mongodb-src-r2.5.5.zip: mongodb-src-r2.5.5/src/mongo/shell/shell_options.h <==
/*
 *    Copyright (C) 2013 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#pragma once

#include <string>
#include <vector>

#include "mongo/base/status.h"

namespace mongo {

    namespace optionenvironment {
        class OptionSection;
        class Environment;
    } // namespace optionenvironment

    namespace moe = mongo::optionenvironment;

    struct ShellGlobalParams {
        std::string url;
        std::string dbhost;
        std::string port;
        std::vector<std::string> files;

        std::string username;
        std::string password;
        bool usingPassword;
        std::string authenticationMechanism;
        std::string authenticationDatabase;

        bool runShell;
        bool nodb;
        bool norc;

        std::string script;

        bool autoKillOp;
        bool useWriteCommandsDefault;

        ShellGlobalParams() : autoKillOp(false), useWriteCommandsDefault(true) { }
    };

    extern ShellGlobalParams shellGlobalParams;

    Status addMongoShellOptions(moe::OptionSection* options);

    std::string getMongoShellHelp(const StringData& name, const moe::OptionSection& options);

    /**
     * Handle options that should come before validation, such as "help".
     *
     * Returns false if an option was found that implies we should prematurely exit with success.
     */
    bool handlePreValidationMongoShellOptions(const moe::Environment& params,
                                                const std::vector<std::string>& args);

    Status storeMongoShellOptions(const moe::Environment& params,
                                  const std::vector<std::string>& args);
}

==> mongodb-src-r3.1.3.zip: mongodb-src-r3.1.3/src/mongo/shell/shell_options.h <==
/*
 *    Copyright (C) 2013 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#pragma once

#include <string>
#include <vector>

#include "mongo/base/status.h"

namespace mongo {

    namespace optionenvironment {
        class OptionSection;
        class Environment;
    } // namespace optionenvironment

    namespace moe = mongo::optionenvironment;

    struct ShellGlobalParams {
        std::string url;
        std::string dbhost;
        std::string port;
        std::vector<std::string> files;

        std::string username;
        std::string password;
        bool usingPassword;
        std::string authenticationMechanism;
        std::string authenticationDatabase;
        std::string gssapiServiceName;
        std::string gssapiHostName;

        bool runShell;
        bool nodb;
        bool norc;

        std::string script;

        bool autoKillOp;
        bool useWriteCommandsDefault;
        std::string writeMode;

        std::string readMode;

        ShellGlobalParams() : autoKillOp(false),
                              useWriteCommandsDefault(true),
                              writeMode("commands"),
                              readMode("compatibility") {
        }
    };

    extern ShellGlobalParams shellGlobalParams;

    Status addMongoShellOptions(moe::OptionSection* options);

    std::string getMongoShellHelp(StringData name, const moe::OptionSection& options);

    /**
     * Handle options that should come before validation, such as "help".
     *
     * Returns false if an option was found that implies we should prematurely exit with success.
     */
    bool handlePreValidationMongoShellOptions(const moe::Environment& params,
                                                const std::vector<std::string>& args);

    Status storeMongoShellOptions(const moe::Environment& params,
                                  const std::vector<std::string>& args);

    Status validateMongoShellOptions(const moe::Environment& params);
}
